@@ -1,10 +1,11 @@
 from datetime import date, datetime
-import aiohttp, asyncio
+from typing import Optional, TypeVar
+import aiohttp, asyncio, re
 
 from ..types.model import Type
-
 from ..exceptions import raise_error, all_error_types_str, all_error_types_str_, APIError, all_error_types_str__dict
 
+_Type = TypeVar("_Type")
 
 class AsyncBaseAPI:
     """
@@ -12,7 +13,7 @@ class AsyncBaseAPI:
     ``(api.school.mosreg.ru)``
     """
     
-    def __init__(self, login: str = None, password: str = None, token: str = None) -> None:
+    def __init__(self, login: Optional[str] = None, password: Optional[str] = None, token: Optional[str] = None) -> None:
         self.login = login
         self.password = password
         self.token = token
@@ -50,17 +51,26 @@ class AsyncBaseAPI:
     def headers(self):
         return {"Access-token": self.token}
     
-    async def get_token(self, params: dict = None):
+    @property
+    def DEFAULT_GET_TOKEN_PARAMS(self):
+        return {
+            "ReturnUrl": (
+                "https://login.school.mosreg.ru/oauth2?"
+                "response_type=token&client_id=bafe713c96a342b194d040392cadf82b"
+                "&scope=EducationalInfo,CommonInfo,FriendsAndRelatives,SocialInfo,ContactInfo"
+            ),
+            "login": self.login, "password": self.password
+        }
+    
+    async def get_token(self, params: Optional[dict] = None):
         """
         Get Token with login&password
         
         :param:params - dict -> {"ReturnUrl": "...", "login": "...", "password": "..."}
         """
-        
-        params = params or {
-            "ReturnUrl": "https://login.school.mosreg.ru/oauth2?response_type=token&client_id=bafe713c96a342b194d040392cadf82b&scope=EducationalInfo,CommonInfo,FriendsAndRelatives,SocialInfo,ContactInfo",
-            "login": self.login, "password": self.password
-        }
+        if not params:
+            params = self.DEFAULT_GET_TOKEN_PARAMS
+            
         URL = "https://login.school.mosreg.ru/login/"
         async with aiohttp.ClientSession() as session:
             async with session.post(URL, headers=self.UserAgentDict, params=params, allow_redirects=True) as resp:
@@ -77,10 +87,9 @@ class AsyncBaseAPI:
                 
                 return resp.real_url.fragment.replace("access_token=", "").replace("&state=", "")
     
-    
-    def ParseListModels(self, model: Type, text: str) -> list[Type]:
+    def ParseListModels(self, model: _Type, text: str) -> list[_Type]:
         class ListModels(Type):
-            listik: list[model]
+            listik: list[model] #type: ignore
         
         return ListModels.parse_raw('{"listik": '+ text.replace("'", '"') + '}').listik
     
@@ -89,7 +98,7 @@ class AsyncBaseAPI:
         if response.content_type == "text/html":
             error_html = await response.text()
             if "502" in error_html:
-                raise_error(url=response.url, status_code=response.status, error_type="HTMLError", description=error_html)
+                raise_error(url=str(response.url), status_code=response.status, error_type="HTMLError", description=error_html)
             
             error_text = " ".join(
                 word
@@ -98,15 +107,15 @@ class AsyncBaseAPI:
                 .strip()[:-4]
                 .split()
             )
-            raise_error(url=response.url, status_code=response.status, error_type="HTMLError", description=error_text)
+            raise_error(url=str(response.url), status_code=response.status, error_type="HTMLError", description=error_text)
         
         json_response = await response.json()
 
         if isinstance(json_response, dict):
             if json_response.get("type") in all_error_types_str or json_response.get("type") in all_error_types_str_ or json_response.get("type") in all_error_types_str__dict.keys():
-                raise_error(url=response.url, status_code=response.status, error_type=json_response.get("type"), description=json_response.get("description", None))
+                raise_error(url=str(response.url), status_code=response.status, error_type=json_response.get("type", "unknownError"), description=json_response.get("description", None))
     
-    async def get(self, method: str, headers: dict = None, model: Type | None = None, is_list: bool = False, return_json: bool = False, return_raw_text: bool = False, **kwargs):
+    async def get(self, method: str, headers: Optional[dict] = None, model: Type | None = None, is_list: bool = False, return_json: bool = False, return_raw_text: bool = False, **kwargs):
         async with aiohttp.ClientSession() as session:
             headers = headers or self.headers
             if headers.get("User-Agent", None) is None:
@@ -125,9 +134,9 @@ class AsyncBaseAPI:
                 elif is_list:
                     return self.ParseListModels(model, (RAW_TEXT))
                 else:
-                    return model.parse_raw((RAW_TEXT))
+                    return model.parse_raw((RAW_TEXT)) if model else await response.json()
     
-    async def post(self, method: str, headers: dict = None, json = None, data = None, model: Type | None = None, is_list: bool = False, return_json: bool = False, return_raw_text: bool = False, **kwargs):
+    async def post(self, method: str, headers: Optional[dict] = None, json = None, data = None, model: Type | None = None, is_list: bool = False, return_json: bool = False, return_raw_text: bool = False, **kwargs):
         async with aiohttp.ClientSession() as session:
             headers = headers or self.headers
             if headers.get("User-Agent", None) is None:
@@ -146,9 +155,9 @@ class AsyncBaseAPI:
                 elif is_list:
                     return self.ParseListModels(model, (RAW_TEXT))
                 else:
-                    return model.parse_raw((RAW_TEXT))
+                    return model.parse_raw((RAW_TEXT)) if model else await response.json()
 
-    async def put(self, method: str, headers: dict = None, json = None, data = None, model: Type | None = None, is_list: bool = False, return_json: bool = False, return_raw_text: bool = False, **kwargs):
+    async def put(self, method: str, headers: Optional[dict] = None, json = None, data = None, model: Type | None = None, is_list: bool = False, return_json: bool = False, return_raw_text: bool = False, **kwargs):
         async with aiohttp.ClientSession() as session:
             headers = headers or self.headers
             if headers.get("User-Agent", None) is None:
@@ -167,9 +176,9 @@ class AsyncBaseAPI:
                 elif is_list:
                     return self.ParseListModels(model, (RAW_TEXT))
                 else:
-                    return model.parse_raw((RAW_TEXT))
+                    return model.parse_raw((RAW_TEXT)) if model else await response.json()
     
-    async def delete(self, method: str, headers: dict = None, json = None, data = None, model: Type | None = None, is_list: bool = False, return_json: bool = False, return_raw_text: bool = False, **kwargs):
+    async def delete(self, method: str, headers: Optional[dict] = None, json = None, data = None, model: Type | None = None, is_list: bool = False, return_json: bool = False, return_raw_text: bool = False, **kwargs):
         async with aiohttp.ClientSession() as session:
             headers = headers or self.headers
             if headers.get("User-Agent", None) is None:
@@ -188,4 +197,4 @@ class AsyncBaseAPI:
                 elif is_list:
                     return self.ParseListModels(model, (RAW_TEXT))
                 else:
-                    return model.parse_raw((RAW_TEXT))
+                    return model.parse_raw((RAW_TEXT)) if model else await response.json()
