@@ -1,29 +1,29 @@
-from pydantic import BaseModel
+from .model import Type
 
-class markNumbers_mark(BaseModel):
+class markNumbers_mark(Type):
     value: str
     count: int
 
 
-class markNumbers(BaseModel):
+class markNumbers(Type):
     markNumber: int
     marks: list[markNumbers_mark]
 
 
-class MarksHistogram(BaseModel):
+class MarksHistogram(Type):
     """Деперсонализированная гистограма оценок всего класса"""
 
 
     markNumbers: list[markNumbers]
 
 
-class WORK(BaseModel):
+class WORK(Type):
     workId: int
     workId_str: str
     markNumbers: list[markNumbers]
 
 
-class MarksHistogramByPeriod(BaseModel):
+class MarksHistogramByPeriod(Type):
     """Деперсонализированная гистограма оценок всего класса за отчетный период"""
     
     works: list[WORK]
\ No newline at end of file
